pub struct Node {
pub value: NodeValue,
pub span: Span,
/* private fields */
}Expand description
Spanful YAML document tree node produced by the parser.
Fields
value: NodeValueParsed node payload.
span: SpanSource span for this node.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn scalar_source(&self) -> Option<&ScalarSource>
pub fn scalar_source(&self) -> Option<&ScalarSource>
Returns the original scalar spelling when it was retained.
Sourcepub fn as_timestamp(&self) -> Option<Timestamp>
pub fn as_timestamp(&self) -> Option<Timestamp>
Returns this node as a YAML 1.1 timestamp, if it carries !!timestamp.
Sourcepub fn equivalent(&self, other: &Self) -> bool
pub fn equivalent(&self, other: &Self) -> bool
Compares two nodes by semantic value, ignoring source spans.
Sourcepub fn into_value(self) -> Value
pub fn into_value(self) -> Value
Converts this spanful node into a spanless Value.