SourceRenderOptions

Struct SourceRenderOptions 

#[non_exhaustive]
pub struct SourceRenderOptions { pub context_lines: usize, }
Options for source-context diagnostic rendering.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
context_lines: usize

Number of source lines to render before and after the primary line.

The default 0 preserves compact rendering with only the diagnostic line. Nonzero values include up to that many neighboring source lines on each side for both primary and related spans.